# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# ruff: noqa: D104
import builtins

from opendal._opendal import (  # noqa: F403
    capability,
    exceptions,
    file,
    layers,
    services,
    types,
)
from opendal.operator import AsyncOperator, Operator  # pyright:ignore

__version__: builtins.str

__all__ = [
    "capability",
    "exceptions",
    "file",
    "layers",
    "services",
    "types",
    "AsyncOperator",
    "Operator",
]
